package
Version:
v0.0.0-...-195f309
Opens a new window with list of versions in this module.
Published: Aug 10, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Crypto struct {
ID primitive.ObjectID `bson:"_id,omitempty"`
Name string `bson:"name" binding:"required"`
Upvote int64 `bson:"upvote"`
Downvote int64 `bson:"downvote"`
Totalscore int64 `bson:"totalscore"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.